"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    PreviewPlugin: function() {
        return PreviewPlugin;
    },
    default: function() {
        return _default;
    }
});
const _define_property = require("@swc/helpers/_/_define_property");
const _interop_require_default = require("@swc/helpers/_/_interop_require_default");
const _state = require("@codemirror/state");
const _view = require("@codemirror/view");
const _constscjs = require("./consts.cjs");
const _PreviewWidgetcjs = /*#__PURE__*/ _interop_require_default._(require("./PreviewWidget.cjs"));
let PreviewPlugin = class PreviewPlugin {
    renderWidgets() {
        const { state } = this.view;
        const { doc } = state;
        const lineCount = doc.lines;
        const decorations = new _state.RangeSetBuilder();
        for(let i = 1; i <= lineCount; i++){
            const line = doc.line(i);
            if (!line.length) {
                continue;
            }
            if (!_constscjs.IMAGE_MATCH_REGEXP.exec(line.text)) {
                continue;
            }
            const matched = _constscjs.IMAGE_CATCH_REGEXP.exec(line.text);
            let url = matched.groups.url;
            if (_constscjs.IMAGE_UPLOADING_FLAG_MATCH.test(url)) {
                const id = url.replace(_constscjs.IMAGE_UPLOADING_FLAG_MATCH, '');
                if (_constscjs.FILE_CACHE.has(id)) {
                    const item = _constscjs.FILE_CACHE.get(id);
                    if (item.url) {
                        url = item.url;
                    } else {
                        url = URL.createObjectURL(item.file);
                        item.url = url;
                    }
                } else {
                    continue;
                }
            }
            if (URL.canParse(url)) {
                const widget = new _PreviewWidgetcjs.default(url);
                decorations.add(line.from, line.from, _view.Decoration.line({
                    class: 'cm-image-preview'
                }));
                decorations.add(line.to, line.to, _view.Decoration.widget({
                    widget
                }));
            }
        }
        this.decorations = decorations.finish();
    }
    update(update) {
        if (update.docChanged) {
            this.renderWidgets();
        }
    }
    constructor(view){
        _define_property._(this, "view", void 0);
        _define_property._(this, "decorations", void 0);
        this.view = view;
        this.decorations = _view.Decoration.none;
        this.renderWidgets();
    }
};
const previewPlugin = ()=>{
    return _view.ViewPlugin.define((view)=>new PreviewPlugin(view), {
        decorations: (v)=>v.decorations,
        provide: (v)=>{
            return _view.EditorView.atomicRanges.of((view)=>{
                return view.plugin(v)?.decorations || _view.Decoration.none;
            });
        }
    });
};
const _default = previewPlugin;
