"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "imageStatusLinter", {
    enumerable: true,
    get: function() {
        return imageStatusLinter;
    }
});
const _lint = require("@codemirror/lint");
const _constscjs = require("./consts.cjs");
const imageStatusLinter = (0, _lint.linter)((view)=>{
    let diagnostics = [];
    const { state } = view;
    const lineCount = state.doc.lines;
    for(let i = 1; i <= lineCount; i++){
        const line = state.doc.line(i);
        if (!line.length) {
            continue;
        }
        const matched = _constscjs.IMAGE_CATCH_REGEXP.exec(line.text);
        if (!matched) {
            continue;
        }
        const { url } = matched.groups;
        const pos = {
            from: line.from + matched.index,
            to: line.from + matched.index + matched[0].length
        };
        if (url.startsWith(`${_constscjs.IMAGE_UPLOADING_FLAG}:`)) {
            const id = url.replace(`${_constscjs.IMAGE_UPLOADING_FLAG}:`, '');
            console.log(id, _constscjs.FILE_CACHE.get(id));
            if (id) {
                const item = _constscjs.FILE_CACHE.get(id);
                if (item) {
                    if (item.status === 'error') {
                        diagnostics.push({
                            ...pos,
                            message: 'Image upload failed, remove this line and try again',
                            severity: 'error'
                        });
                        continue;
                    } else if (item.status === 'uploading') {
                        diagnostics.push({
                            ...pos,
                            message: 'Image is uploading',
                            severity: 'error'
                        });
                        continue;
                    }
                }
            }
            diagnostics.push({
                ...pos,
                message: 'Invalid uploading image, remove this line and try again',
                severity: 'error'
            });
            continue;
        }
        if (!URL.canParse(url)) {
            diagnostics.push({
                ...pos,
                message: 'Invalid image file',
                severity: 'error'
            });
        }
    }
    return diagnostics;
});
